<?php

/*
Plugin Name: WP Cookies Bar
Plugin URI: http://michalmleczko.waw.pl/sklep/
Description: Dodaje pasek na dole z powiadomieniem o ciasteczkach
Version: 1.0
Author: Michał Mleczko
Author URI: http://michalmleczko.waw.pl/
Text Domain: wp-cookies-bar
Domain Path: /lang
 */

require_once plugin_dir_path( __FILE__ ) . '/Class/MySettingPage.php';


define( 'WP_COOKIES_BAR_FILE', __FILE__ );
define( 'WP_COOKIES_BAR_PATH', plugin_dir_path( __FILE__ ) );

$wpCookiesBar = new WPCookiesBar();

class WPCookiesBar {

	public function __construct() {

		add_action( 'init', array( $this, 'init' ) );

		// Listen for the activate event
		register_activation_hook( WP_COOKIES_BAR_FILE, array( $this, 'activate' ) );

		// Deactivation plugin
		register_deactivation_hook( WP_COOKIES_BAR_FILE, array( $this, 'deactivate' ) );
	}

	public function activate() {
		update_option( 'wp_cookies_bar_path', null );
	}

	public function deactivate() {
		delete_option( 'wp_cookies_bar_path' );
	}

	public function init() {

		// This will show the stylesheet in wp_head() in the app/index.php file
		wp_enqueue_style( 'wp-cookies-bar-stylesheet', plugins_url( 'wp-cookies-bar/wp-cookies-bar.css' ) );
	}

	// Localization
	function localizationsample_init() {
		$path   = dirname( plugin_basename( __FILE__ ) ) . '/lang/';
		$loaded = load_plugin_textdomain( 'wp-cookies-bar', false, $path );
	}

	// Add entry in the settings menu
	public function add_page() {
		add_action( 'plugin_action_links_' . plugin_basename( __FILE__ ), array(
			$this,
			'wp_cookies_bar_filter_plugin_actions'
		) );
	}

	// Add settings option
	public function wp_cookies_bar_filter_plugin_actions( $links ) {
		$new_links = array();

		$new_links[] = '<a href="' . admin_url( "options-general.php?page=wp-cookies-bar" ) . '">' . __( 'Settings', 'wp-cookies-bar' ) . '</a>';

		return array_merge( $new_links, $links );
	}

	function display_block() {
		$policy = get_option( 'wp_cookies_bar_path' );
		?>
		<div class="wp-cookies-bar" style="display: none;">
			<div class="cookies-container">
				<span class="cookie-icon"></span>
				Ta strona używa plików cookies w celu realizacji usług
				<?php
				if ($policy) :
				?> i zgodnie z <a href="<?php echo get_permalink( $policy ); ?>">Polityką Plików Cookies</a>
				<?php endif;
				?>.
				<button class="cookies-close-button">OK</button>
			</div>
		</div>
		<script>
			jQuery(document).ready(function () {
				if (!wpCookieBarReadCookie('wpCookieBar')) {
					jQuery('.wp-cookies-bar').slideDown();
				}
				jQuery('.cookies-close-button').on('click', function () {
					wpCookieBarCreateCookie('wpCookieBar', 1);
					jQuery('.wp-cookies-bar').slideUp();
				})
			});

			function wpCookieBarCreateCookie(name, value, days) {
				if (days) {
					var date = new Date();
					date.setTime(date.getTime() + (days * 24 * 60 * 60 * 1000));
					var expires = "; expires=" + date.toGMTString();
				}
				else var expires = "";

				document.cookie = name + "=" + value + expires + "; path=/";
			}

			function wpCookieBarReadCookie(name) {
				var nameEQ = name + "=";
				var ca = document.cookie.split(';');
				for (var i = 0; i < ca.length; i++) {
					var c = ca[i];
					while (c.charAt(0) == ' ') c = c.substring(1, c.length);
					if (c.indexOf(nameEQ) == 0) return c.substring(nameEQ.length, c.length);
				}
				return null;
			}
		</script>
		<?php

	}
}

add_action( 'wp_footer', array( $wpCookiesBar, 'display_block' ) );

if ( is_admin() ) {
	add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), array(
		$wpCookiesBar,
		'wp_cookies_bar_filter_plugin_actions'
	) );

	$my_settings_page = new WPCookiesBarSettingsPage();
}

add_action( 'init', array( $wpCookiesBar, 'localizationsample_init' ) );


